
### Overview
Watch how Laktory brings your data vision to life by deploying and executing your pipeline definition.

![type:video](https://www.youtube.com/embed/dlaUQm5yUa4)

### Requests
You may request a live demo from Okube [website](https://www.okube.ai/contact).